@@ -34,10 +34,6 @@
 #include <sys/types.h>
 #include <unistd.h>
 
-#include <QFile>
-#include <QTextStream>
-#include <QDebug>
-
 #include <QCoreApplication>
 #include <QStandardPaths>
 
@@ -801,7 +797,7 @@ void KameraProtocol::listDir(const QUrl &yurl)
         gp_list_free(dirList);
         gp_list_free(fileList);
         gp_list_free(specialList);
-        error(KIO::ERR_SLAVE_DEFINED, i18n("Could not read. Reason: %1",
+        error(KIO::ERR_WORKER_DEFINED, i18n("Could not read. Reason: %1",
                     QString::fromLocal8Bit(gp_result_as_string(gpr))));
         return;
     }
